# generated by datamodel-codegen:
#   filename:  network.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    io_counters_bytes_sent: float | None = None
    io_counters_bytes_recv: float | None = None
    io_counters_packets_sent: float | None = None
    io_counters_packets_recv: float | None = None
    io_counters_errin: float | None = None
    io_counters_errout: float | None = None
    io_counters_dropin: float | None = None
    io_counters_dropout: float | None = None


class Network(BaseModel):
    """
    Network
    """

    class Config:
        extra = Extra.allow

    id: str | None = Field(None, description="Event ID")
    io_counters_bytes_sent: int | None = None
    io_counters_bytes_recv: int | None = None
    io_counters_packets_sent: int | None = None
    io_counters_packets_recv: int | None = None
    io_counters_errin: int | None = None
    io_counters_errout: int | None = None
    io_counters_dropin: int | None = None
    io_counters_dropout: int | None = None
    last_updated: LastUpdated | None = Field(None, description="Last updated")
